#include <OneWire.h>
#include <DallasTemperature.h>
#include <LiquidCrystal_I2C.h>
#include "BluetoothSerial.h"

#if !defined(CONFIG_BT_ENABLED) || !defined(CONFIG_BLUEDROID_ENABLED)
#error Bluetooth is not enabled! Please run `make menuconfig` to and enable it
#endif

BluetoothSerial SerialBT;

String message = "";
char incomingChar;
String temperatureString = "";
String humidityString = "";

#define ADC_VREF_mV    4755.0
#define ADC_RESOLUTION 4096.0
#define MQ135       39
#define TEMP_REF       34

const int oneWireBus = 4;    


LiquidCrystal_I2C lcd(0x27, 16, 2);
const int SW = 19;
const int BUZZAR = 17;
const int EV_ECU = 5;
const float threshold2=400.00;


OneWire oneWire(oneWireBus);

DallasTemperature sensors(&oneWire);

void setup() {
  lcd.init();        
  lcd.backlight();  

  Serial.begin(115200);
  SerialBT.begin("ESP32");
  Serial.println("Start pairing!");

  pinMode(SW, INPUT);  
  pinMode(BUZZAR, OUTPUT);
  pinMode(EV_ECU, OUTPUT);
  sensors.begin();
}

void loop() {

  if (digitalRead(SW) == HIGH){  
  int adcVal2= analogRead(TEMP_REF);
  float milliVolt2 = adcVal2 * (ADC_VREF_mV / ADC_RESOLUTION);
  float temp_r = milliVolt2 / 8.5;
  lcd.clear();
  lcd.setCursor(0, 0);  
  lcd.print("REF_TEMP:");
  lcd.print(temp_r);  
  lcd.print("C");
  SerialBT.println("Alarm_Temp_REF");
  SerialBT.println(temp_r);
  delay(500);
  }

  else if (digitalRead(SW) == LOW)
 {
 
    int adcVal1= analogRead(MQ135);
    int adcVal3 = analogRead(TEMP_REF);
    float milliVolt3 = adcVal3 * (ADC_VREF_mV / ADC_RESOLUTION);
    float temp_rr = milliVolt3 / 8.5;
    float milliVolt1 = adcVal1 * (ADC_VREF_mV / ADC_RESOLUTION);
    float AIR_PPM = milliVolt1 / 1;  
    sensors.requestTemperatures();
    int temperatureD = sensors.getTempCByIndex(0);
    float temperatureC = sensors.getTempCByIndex(0);
    float temperatureF = sensors.getTempFByIndex(0);
    SerialBT.println(temperatureD);

if(temperatureC>temp_rr)
  {
    SerialBT.println("Temperature_Alarm");
    lcd.clear();
    lcd.setCursor(0, 0);  
    lcd.print("Temperature_Alarm");
    digitalWrite(BUZZAR, HIGH);
    digitalWrite(EV_ECU, HIGH);
    delay(60000);
           
      }

      else if(temperatureC<temp_rr)
      {
        SerialBT.println(temperatureD);
        lcd.clear();
        lcd.setCursor(0, 0);
        lcd.print("T:");
        lcd.print(temperatureC);
        lcd.print("C");
        lcd.setCursor(0, 1);  
        lcd.print("Air:");
        lcd.print(AIR_PPM);
        lcd.print("PPM");
        digitalWrite(BUZZAR, LOW);
        digitalWrite(EV_ECU, LOW);

        }

      else if(AIR_PPM>threshold2)
  {
   
    SerialBT.println("Smoke_Alarm");
    lcd.setCursor(0, 0);  
    lcd.print("Smoke_Alarm");    
    digitalWrite(BUZZAR, HIGH);
    digitalWrite(EV_ECU, HIGH);
    delay(60000);
 
      }

}
}
